#include "tqpaintdevicemetrics.h"

#ifdef USE_QT4

/****************************************************************************
**
** Copyright (C) 2010 Nokia Corporation and/or its subsidiary(-ies).
** All rights reserved.
** Contact: Nokia Corporation (qt-info@nokia.com)
**
** This file is part of the Qt3Support module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial Usage
** Licensees holding valid Qt Commercial licenses may use this file in
** accordance with the Qt Commercial License Agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Nokia.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Nokia gives you certain additional
** rights.  These rights are described in the Nokia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
** If you have questions regarding the use of this file, please contact
** Nokia at qt-info@nokia.com.
** $QT_END_LICENSE$
**
****************************************************************************/

QT_BEGIN_NAMESPACE

/*!
    \class TQPaintDeviceMetrics
    \brief The TQPaintDeviceMetrics class provides information about a
    paint tqdevice.

    \compat

    Sometimes when drawing graphics it is necessary to obtain
    information about the physical characteristics of a paint tqdevice.
    This class provides the information. For example, to compute the
    aspect ratio of a paint tqdevice:

    \snippet doc/src/snippets/code/src_qt3support_painting_q3painttqdevicemetrics.cpp 0

    TQPaintDeviceMetrics contains methods to provide the width and
    height of a tqdevice in both pixels (width() and height()) and
    millimeters (widthMM() and heightMM()), the number of colors the
    tqdevice supports (numColors()), the number of bit planes (depth()),
    and the resolution of the tqdevice (logicalDpiX() and
    logicalDpiY()).

    It is not always possible for TQPaintDeviceMetrics to compute the
    values you ask for, particularly for external tqdevices. The
    ultimate example is asking for the resolution of of a QPrinter
    that is set to "print to file": who knows what printer that file
    will end up on?
*/

/*!
  \fn TQPaintDeviceMetrics::TQPaintDeviceMetrics(const QPaintDevice *pd)

    Constructs a metric for the paint tqdevice \a pd.
*/


/*!
    \fn int TQPaintDeviceMetrics::width() const

    Returns the width of the paint tqdevice in default coordinate system
    units (e.g. pixels for QPixmap and QWidget).
*/

/*!
    \fn int TQPaintDeviceMetrics::height() const

    Returns the height of the paint tqdevice in default coordinate
    system units (e.g. pixels for QPixmap and QWidget).
*/

/*!
    \fn int TQPaintDeviceMetrics::widthMM() const

    Returns the width of the paint tqdevice, measured in millimeters.
*/

/*!
    \fn int TQPaintDeviceMetrics::heightMM() const

    Returns the height of the paint tqdevice, measured in millimeters.
*/

/*!
    \fn int TQPaintDeviceMetrics::numColors() const

    Returns the number of different colors available for the paint
    tqdevice. Since this value is an int will not be sufficient to represent
    the number of colors on 32 bit displays, in which case INT_MAX is
    returned instead.
*/

/*!
    \fn int TQPaintDeviceMetrics::depth() const

    Returns the bit depth (number of bit planes) of the paint tqdevice.
*/

/*!
    \fn int TQPaintDeviceMetrics::logicalDpiX() const

    Returns the horizontal resolution of the tqdevice in dots per inch,
    which is used when computing font sizes. For X, this is usually
    the same as could be computed from widthMM(), but it varies on
    Windows.
*/

/*!
    \fn int TQPaintDeviceMetrics::logicalDpiY() const

    Returns the vertical resolution of the tqdevice in dots per inch,
    which is used when computing font sizes. For X, this is usually
    the same as could be computed from heightMM(), but it varies on
    Windows.
*/

/*!
    \fn int TQPaintDeviceMetrics::physicalDpiX() const
    \internal
*/
/*!
    \fn int TQPaintDeviceMetrics::physicalDpiY() const
    \internal
*/

QT_END_NAMESPACE

#else // USE_QT4

/****************************************************************************
**
** Implementation of TQPaintDeviceMetrics class
**
** Created : 941109
**
** Copyright (C) 2010 Timothy Pearson and (C) 1992-2008 Trolltech ASA.
**
** This file is part of the kernel module of the TQt GUI Toolkit.
**
** This file may be used under the terms of the GNU General
** Public License versions 2.0 or 3.0 as published by the Free
** Software Foundation and appearing in the files LICENSE.GPL2
** and LICENSE.GPL3 included in the packaging of this file.
** Alternatively you may (at your option) use any later version
** of the GNU General Public License if such license has been
** publicly approved by Trolltech ASA (or its successors, if any)
** and the KDE Free TQt Foundation.
**
** Please review the following information to ensure GNU General
** Public Licensing requirements will be met:
** http://trolltech.com/products/qt/licenses/licensing/opensource/.
** If you are unsure which license is appropriate for your use, please
** review the following information:
** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
** or contact the sales department at sales@trolltech.com.
**
** This file may be used under the terms of the Q Public License as
** defined by Trolltech ASA and appearing in the file LICENSE.TQPL
** included in the packaging of this file.  Licensees holding valid TQt
** Commercial licenses may use this file in accordance with the TQt
** Commercial License Agreement provided with the Software.
**
** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
** A PARTICULAR PURPOSE. Trolltech reserves all rights not granted
** herein.
**
**********************************************************************/

/*!
    \class TQPaintDeviceMetrics tqpaintdevicemetrics.h
    \brief The TQPaintDeviceMetrics class provides information about a
    paint tqdevice.

    \ingroup graphics
    \ingroup images

    Sometimes when drawing graphics it is necessary to obtain
    information about the physical characteristics of a paint tqdevice.
    This class provides the information. For example, to compute the
    aspect ratio of a paint tqdevice:

    \code
	TQPaintDeviceMetrics pdm( myWidget );
	double aspect = (double)pdm.widthMM() / (double)pdm.heightMM();
    \endcode

    TQPaintDeviceMetrics contains methods to provide the width and
    height of a tqdevice in both pixels (width() and height()) and
    millimeters (widthMM() and heightMM()), the number of colors the
    tqdevice supports (numColors()), the number of bit planes (depth()),
    and the resolution of the tqdevice (logicalDpiX() and
    logicalDpiY()).

    It is not always possible for TQPaintDeviceMetrics to compute the
    values you ask for, particularly for external tqdevices. The
    ultimate example is asking for the resolution of of a TQPrinter
    that is set to "print to file": who knows what printer that file
    will end up on?
*/

/*!
    Constructs a metric for the paint tqdevice \a pd.
*/
TQPaintDeviceMetrics::TQPaintDeviceMetrics( const TQPaintDevice *pd )
{
    pdev = (TQPaintDevice *)pd;
}


/*!
    \fn int TQPaintDeviceMetrics::width() const

    Returns the width of the paint tqdevice in default coordinate system
    units (e.g. pixels for TQPixmap and TQWidget).
*/

/*!
    \fn int TQPaintDeviceMetrics::height() const

    Returns the height of the paint tqdevice in default coordinate
    system units (e.g. pixels for TQPixmap and TQWidget).
*/

/*!
    \fn int TQPaintDeviceMetrics::widthMM() const

    Returns the width of the paint tqdevice, measured in millimeters.
*/

/*!
    \fn int TQPaintDeviceMetrics::heightMM() const

    Returns the height of the paint tqdevice, measured in millimeters.
*/

/*!
    \fn int TQPaintDeviceMetrics::numColors() const

    Returns the number of different colors available for the paint
    tqdevice. Since this value is an int will not be sufficient to represent
    the number of colors on 32 bit displays, in which case INT_MAX is
    returned instead.
*/

/*!
    \fn int TQPaintDeviceMetrics::depth() const

    Returns the bit depth (number of bit planes) of the paint tqdevice.
*/

/*!
    \fn int TQPaintDeviceMetrics::logicalDpiX() const

    Returns the horizontal resolution of the tqdevice in dots per inch,
    which is used when computing font sizes. For X, this is usually
    the same as could be computed from widthMM(), but it varies on
    Windows.
*/

/*!
    \fn int TQPaintDeviceMetrics::logicalDpiY() const

    Returns the vertical resolution of the tqdevice in dots per inch,
    which is used when computing font sizes. For X, this is usually
    the same as could be computed from heightMM(), but it varies on
    Windows.
*/

/*!
    \fn int TQPaintDeviceMetrics::physicalDpiX() const
    \internal
*/
/*!
    \fn int TQPaintDeviceMetrics::physicalDpiY() const
    \internal
*/

#endif // USE_QT4